Fixed function not found issue

[ROCm/clr commit: 2ff9e5d46d]
Этот коммит содержится в:
Rahul Garg
2018-03-16 12:35:25 +05:30
родитель 05a7963b07
Коммит c2f4352aad
+1 -1
Просмотреть файл
@@ -23,7 +23,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
extern texture<float, 2, hipReadModeElementType> tex;
__global__ void tex2dKernel(hipLaunchParm lp, float* outputData, int width, int height) {
extern "C" __global__ void tex2dKernel(hipLaunchParm lp, float* outputData, int width, int height) {
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;
int y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;
outputData[y * width + x] = tex2D(tex, x, y);